proxy — Health Dashboard

# proxy — Good

Analyzed 2026-03-23 by code2llm · Primary language: python · Python: 108, JavaScript: 28, Shell: 7

1,265
Functions
111
Classes
127
Files
38,539
Lines
3
Languages
3.6
Avg CC
77
Critical (CC≥10)
0
Duplicates
0
Cycles

## Language Distribution

## Largest Modules (lines)

## Most Complex Modules (functions)

## Evolution

## Top Modules (143)

Module | Path | Lines | Funcs | Classes | CC max
--- | --- | --- | --- | --- | ---
tools.jsx | src/proxym/dashboard/components | 881 | 57 | 0 | 35
coverage_html_cb_dd2e7eb5.js | htmlcov | 735 | 65 | 0 | 21
tasks.jsx | src/proxym/dashboard/components | 557 | 49 | 0 | 24
tickets.jsx | src/proxym/dashboard/components | 491 | 20 | 0 | 20
projects.jsx | src/proxym/dashboard/components | 467 | 22 | 0 | 21
validate_system.sh | scripts | 462 | 10 | 0 | 0
__init__.py | src/proxym/tools | 421 | 13 | 5 | 7
tickets.py | src/proxym/dashboard | 387 | 23 | 10 | 17
adapters.py | src/proxym/tools | 366 | 13 | 6 | 7
frontend.py | src/proxym/api | 363 | 31 | 0 | 6
__init__.py | src/proxym/router | 357 | 14 | 1 | 9
__init__.py | src/proxym/accounts | 350 | 20 | 8 | 10
repair_agent.py | src/proxym/observability | 341 | 9 | 1 | 14
__init__.py | src/proxym/cache | 333 | 10 | 3 | 9
entrypoint.sh | services/vscode | 333 | 1 | 0 | 0
__init__.py | src/proxym/providers | 331 | 4 | 3 | 8
_tickets_api.py | src/proxym/dashboard | 329 | 15 | 6 | 6
browser_profiles.py | src/proxym/virt | 325 | 11 | 2 | 9
_tools_api.py | src/proxym/dashboard | 319 | 16 | 2 | 12
tickets.py | src/proxym/cli | 311 | 13 | 0 | 12

## Alerts (20)

Severity | Target | Type | Value | Limit
--- | --- | --- | --- | ---
critical | TicketDispatchTable | cc_exceeded | 35 | 15
critical | LogPanel | cc_exceeded | 34 | 15
critical | JobDetailsPanel | cc_exceeded | 34 | 15
critical | VMsPanel | cc_exceeded | 32 | 15
critical | useDashboardData | high_fan_out | 31 | 10
critical | VoiceChat | high_fan_out | 31 | 10
critical | DiagRooConfig | cc_exceeded | 29 | 15
critical | run_all_tests | high_fan_out | 28 | 10
critical | chat_completions | high_fan_out | 27 | 10
critical | DiagnosticsPanel | cc_exceeded | 26 | 15
critical | create_ticket | high_fan_out | 23 | 10
critical | TableExport | high_fan_out | 23 | 10
critical | TableExport | high_fan_out | 23 | 10
critical | TableExport | high_fan_out | 23 | 10
critical | DiagnosticsPanel | high_fan_out | 22 | 10

## Hotspots (10)

Function | Fan-out | Note
--- | --- | ---
useDashboardData | 31 | Orchestrates 31 calls
VoiceChat | 31 | Orchestrates 31 calls
run_all_tests | 28 | Run all diagnostic tests and return comprehensive status.
chat_completions | 27 | OpenAI-compatible chat completions with intelligent routing. Extra headers: X
create_ticket | 23 | Create a new ticket. Accepts 'task' (new) or 'title' (legacy).
TableExport | 23 | Export with 23 outputs
TableExport | 23 | Export with 23 outputs
TableExport | 23 | Export with 23 outputs
DiagnosticsPanel | 22 | Orchestrates 22 calls
TicketDispatchTable | 22 | 22-way dispatch

## Refactoring Priorities (15)

# | Action | Impact | Effort
--- | --- | --- | ---
1 | Split DiagnosticsPanel (CC=26 → target CC<10) | high | low
2 | Split LogPanel (CC=34 → target CC<10) | high | low
3 | Split VMsPanel (CC=32 → target CC<10) | high | low
4 | Split JobDetailsPanel (CC=34 → target CC<10) | high | low
5 | Split TicketDispatchTable (CC=35 → target CC<10) | high | low
6 | Split DiagRooConfig (CC=29 → target CC<10) | high | low
7 | Split god module src/proxym/dashboard/components/tools.jsx (881L, 0 classes) | high | high
8 | Split god module src/proxym/dashboard/components/tasks.jsx (557L, 0 classes) | high | high
9 | Split god module htmlcov/coverage_html_cb_dd2e7eb5.js (735L, 0 classes) | high | high
10 | Split TicketManager._apply_filters (CC=17 → target CC<10) | medium | low
11 | Split TicketManager.update_ticket (CC=16 → target CC<10) | medium | low
12 | Split ProjectRegistry._enrich_local (CC=21 → target CC<10) | medium | low
13 | Split check_providers_config (CC=19 → target CC<10) | medium | low
14 | Split VoiceChat (CC=24 → target CC<10) | medium | low
15 | Split table (CC=21 → target CC<10) | medium | low